@@ -12,7 +12,12 @@ from great_expectations.checkpoint import ValidationAction
 from great_expectations.core import ExpectationSuiteValidationResult
 from great_expectations.data_context.types.resource_identifiers import ValidationResultIdentifier
 from great_expectations.dataset import SqlAlchemyDataset, PandasDataset, Dataset as GEDataset
-
+from great_expectations.execution_engine import (
+    PandasExecutionEngine,
+    SqlAlchemyExecutionEngine,
+)
+from great_expectations.execution_engine.sqlalchemy_batch_data import SqlAlchemyBatchData
+from great_expectations.validator.validator import Validator
 from openlineage.client import OpenLineageClient, OpenLineageClientOptions
 from openlineage.client.facet import ParentRunFacet, DocumentationJobFacet, \
     SourceCodeLocationJobFacet, DataQualityMetricsInputDatasetFacet, ColumnMetric
@@ -29,7 +34,7 @@ from openlineage.common.provider.great_expectations.facets import \
 from openlineage.common.provider.great_expectations.results import EXPECTATIONS_PARSERS, \
     COLUMN_EXPECTATIONS_PARSER, \
     GreatExpectationsAssertion
-from openlineage.common.sql import SqlParser
+from openlineage.common.sql.parser import parse
 
 
 class OpenLineageValidationAction(ValidationAction):
@@ -92,9 +97,10 @@ class OpenLineageValidationAction(ValidationAction):
         self.code_location = code_location
         self.do_publish = do_publish
 
-    def _run(self, validation_result_suite: ExpectationSuiteValidationResult,
+    def _run(self,
+             validation_result_suite: ExpectationSuiteValidationResult,
              validation_result_suite_identifier: ValidationResultIdentifier,
-             data_asset: GEDataset,
+             data_asset: [GEDataset, Validator],
              expectation_suite_identifier=None,
              checkpoint_identifier=None,
              payload=None):
@@ -102,9 +108,9 @@ class OpenLineageValidationAction(ValidationAction):
         self.log = logging.getLogger(self.__class__.__module__ + '.' + self.__class__.__name__)
 
         datasets = []
-        if isinstance(data_asset, SqlAlchemyDataset):
+        if isinstance(data_asset.execution_engine, SqlAlchemyExecutionEngine):
             datasets = self._fetch_datasets_from_sql_source(data_asset, validation_result_suite)
-        elif isinstance(data_asset, PandasDataset):
+        elif isinstance(data_asset.execution_engine, PandasExecutionEngine):
             datasets = self._fetch_datasets_from_pandas_source(data_asset, validation_result_suite)
         run_facets = {}
         if self.parent_run_id is not None:
@@ -114,7 +120,10 @@ class OpenLineageValidationAction(ValidationAction):
                 self.parent_job_name
             )})
         run_facets.update(
-            {"great_expectations_meta": GreatExpectationsRunFacet(**validation_result_suite.meta)})
+            {"great_expectations_meta": GreatExpectationsRunFacet(
+                **validation_result_suite.meta,
+                expectation_suite_meta=validation_result_suite.meta
+            )})
         job_facets = {}
         if self.job_description:
             job_facets.update({
@@ -136,7 +145,7 @@ class OpenLineageValidationAction(ValidationAction):
             job=Job(self.namespace, job_name, facets=job_facets),
             inputs=datasets,
             outputs=[],
-            producer="https://github.com/OpenLineage/OpenLineage/tree/$VERSION/integration/common/openlineage/provider/great_expectations" # noqa
+            producer="https://github.com/OpenLineage/OpenLineage/tree/$VERSION/integration/common/openlineage/provider/great_expectations"  # noqa
         )
         if self.do_publish:
             self.openlineage_client.emit(run_event)
@@ -144,7 +153,7 @@ class OpenLineageValidationAction(ValidationAction):
         return Serde.to_dict(run_event)
 
     def _fetch_datasets_from_pandas_source(self, data_asset: PandasDataset,
-                                           validation_result_suite: ExpectationSuiteValidationResult) -> List[OLDataset]: # noqa
+                                           validation_result_suite: ExpectationSuiteValidationResult) -> List[OLDataset]:  # noqa
         """
         Generate a list of OpenLineage Datasets from a PandasDataset
         :param data_asset:
@@ -169,8 +178,8 @@ class OpenLineageValidationAction(ValidationAction):
                 ).to_openlineage_dataset()
             ]
 
-    def _fetch_datasets_from_sql_source(self, data_asset: SqlAlchemyDataset,
-                                        validation_result_suite: ExpectationSuiteValidationResult) -> List[OLDataset]: # noqa
+    def _fetch_datasets_from_sql_source(self, data_asset: [SqlAlchemyDataset, Validator],
+                                        validation_result_suite: ExpectationSuiteValidationResult) -> List[OLDataset]:  # noqa
         """
         Generate a list of OpenLineage Datasets from a SqlAlchemyDataset.
         :param data_asset:
@@ -178,55 +187,101 @@ class OpenLineageValidationAction(ValidationAction):
         :return:
         """
         metadata = MetaData()
-        if data_asset.generated_table_name is not None:
-            custom_sql = data_asset.batch_kwargs.get('query')
-            parsed_sql = SqlParser.parse(custom_sql)
+        if isinstance(data_asset, SqlAlchemyDataset):
+            if data_asset.generated_table_name is not None:
+                custom_sql = data_asset.batch_kwargs.get('query')
+                parsed_sql = parse(custom_sql)
+                return [
+                    self._get_sql_table(data_asset, metadata, t.schema, t.name,
+                                        validation_result_suite) for t in
+                    parsed_sql.in_tables
+                ]
+            return [self._get_sql_table(data_asset, metadata, data_asset._table.schema,
+                                        data_asset._table.name,
+                                        validation_result_suite)]
+        else:
+            batch = data_asset.active_batch
+            batch_data = batch["data"]
+            table_name = batch["batch_spec"]["table_name"]
+            try:
+                schema_name = batch["batch_spec"]["schema_name"]
+            except KeyError:
+                schema_name = None
             return [
-                self._get_sql_table(data_asset, metadata, t.schema, t.name,
-                                    validation_result_suite) for t in
-                parsed_sql.in_tables
+                self._get_sql_table(
+                    batch_data,
+                    metadata,
+                    schema_name,
+                    table_name,
+                    validation_result_suite
+                )
             ]
-        return [self._get_sql_table(data_asset, metadata, data_asset._table.schema,
-                                    data_asset._table.name,
-                                    validation_result_suite)]
 
-    def _get_sql_table(self, data_asset: SqlAlchemyDataset,
-                       meta: MetaData,
-                       schema: str,
-                       table_name: str,
-                       validation_result_suite: ExpectationSuiteValidationResult) -> Optional[OLDataset]: # noqa
+    def _get_sql_table(
+        self,
+        data_asset: [SqlAlchemyDataset, SqlAlchemyBatchData],
+        meta: MetaData,
+        schema: Optional[str],
+        table_name: str,
+        validation_result_suite: ExpectationSuiteValidationResult
+    ) -> Optional[OLDataset]:
         """
         Construct a Dataset from the connection url and the columns returned from the
         SqlAlchemyDataset
         :param data_asset:
         :return:
         """
-        engine = data_asset.engine
-        if isinstance(engine, Connection):
-            engine = engine.engine
-        datasource_url = engine.url
-        if engine.dialect.name.lower() == "bigquery":
-            schema = '{}.{}'.format(datasource_url.host, datasource_url.database)
+        if isinstance(data_asset, SqlAlchemyDataset):
+            engine = data_asset.engine
+            if isinstance(engine, Connection):
+                engine = engine.engine
+            datasource_url = engine.url
+            if engine.dialect.name.lower() == "bigquery":
+                schema = '{}.{}'.format(datasource_url.host, datasource_url.database)
 
-        table = Table(table_name, meta, autoload_with=engine)
+            table = Table(table_name, meta, autoload_with=engine)
 
-        fields = [Field(
-            name=key,
-            type=str(col.type) if col.type is not None else 'UNKNOWN',
-            description=col.doc
-        ) for key, col in table.columns.items()]
+            fields = [Field(
+                name=key,
+                type=str(col.type) if col.type is not None else 'UNKNOWN',
+                description=col.doc
+            ) for key, col in table.columns.items()]
 
-        name = table_name \
-            if schema is None \
-            else "{}.{}".format(schema, table_name)
+            name = table_name \
+                if schema is None \
+                else "{}.{}".format(schema, table_name)
 
-        results_facet = self.results_facet(validation_result_suite)
-        return Dataset(
-            source=self._source(urlparse(str(datasource_url))),
-            fields=fields,
-            name=name,
-            input_facets=results_facet
-        ).to_openlineage_dataset()
+            results_facet = self.results_facet(validation_result_suite)
+            return Dataset(
+                source=self._source(urlparse(str(datasource_url))),
+                fields=fields,
+                name=name,
+                input_facets=results_facet
+            ).to_openlineage_dataset()
+        # Check for V3 API type
+        if isinstance(data_asset, SqlAlchemyBatchData):
+            engine = data_asset._engine
+            if isinstance(engine, Connection):
+                engine = engine.engine
+            datasource_url = engine.url
+            table = Table(table_name, meta, autoload_with=engine)
+
+            fields = [Field(
+                name=key,
+                type=str(col.type) if col.type is not None else 'UNKNOWN',
+                description=col.doc
+            ) for key, col in table.columns.items()]
+
+            name = table_name \
+                if schema is None \
+                else f"{schema}.{table_name}"
+            results_facet = self.results_facet(validation_result_suite)
+            return Dataset(
+                source=self._source(urlparse(str(datasource_url))),
+                fields=fields,
+                name=name,
+                input_facets=results_facet
+            ).to_openlineage_dataset()
 
     def _source(self, url) -> Source:
         """
