@@ -7,11 +7,81 @@ import sqlparse
 from sqlparse.sql import T, TokenList, Parenthesis, Identifier, IdentifierList
 from sqlparse.tokens import Punctuation
 
-from openlineage.common.models import DbTableName
 
 log = logging.getLogger(__name__)
 
 
+def provider():
+    return "python"
+
+
+class DbTableMeta:
+    def __init__(self, value: str):
+        parts = value.strip().split('.')
+        if len(parts) > 3:
+            raise ValueError(
+                f"Expected 'database.schema.table', found '{value}'."
+            )
+        self.database = self._get_database(parts)
+        self.schema = self._get_schema(parts)
+        self.name = self._get_table(parts)
+        self.qualified_name = self._get_qualified_name()
+
+    def has_database(self) -> bool:
+        return self.database is not None
+
+    def has_schema(self) -> bool:
+        return self.schema is not None
+
+    def _get_database(self, parts) -> str:
+        # {database.schema.table}
+        return parts[0] if len(parts) == 3 else None
+
+    def _get_schema(self, parts) -> str:
+        # {database.schema.table) or {schema.table}
+        return parts[1] if len(parts) == 3 else (
+            parts[0] if len(parts) == 2 else None
+        )
+
+    def _get_table(self, parts) -> str:
+        # {database.schema.table} or {schema.table} or {table}
+        return parts[2] if len(parts) == 3 else (
+            parts[1] if len(parts) == 2 else parts[0]
+        )
+
+    def _get_qualified_name(self) -> str:
+        return (
+            f"{self.database}.{self.schema}.{self.name}"
+            if self.has_database() else (
+                f"{self.schema}.{self.name}" if self.has_schema() else self.name
+            )
+        )
+
+    def __hash__(self):
+        return hash(self.qualified_name)
+
+    def __eq__(self, other):
+        return self.database == other.database and \
+               self.schema == other.schema and \
+               self.name == other.name and \
+               self.qualified_name == other.qualified_name
+
+    def __repr__(self):
+        # Return the string representation of the instance
+        return (
+            f"DbTableMeta({self.database!r},{self.schema!r},"
+            f"{self.name!r},{self.qualified_name!r})"
+        )
+
+    def __str__(self):
+        # Return the fully qualified table name as the string representation
+        # of this object, otherwise the table name only
+        return (
+            self.qualified_name
+            if (self.has_database() or self.has_schema()) else self.name
+        )
+
+
 def _is_in_table(token):
     return _match_on(token, [
         'FROM',
@@ -38,7 +108,7 @@ def _get_tables(
         tokens,
         idx,
         default_schema: Optional[str] = None
-) -> Tuple[int, List[DbTableName]]:
+) -> Tuple[int, List[DbTableMeta]]:
     # Extract table identified by preceding SQL keyword at '_is_in_table'
     def parse_ident(ident: Identifier) -> str:
         # Extract table name from possible schema.table naming
@@ -84,22 +154,22 @@ def _get_tables(
     else:
         tables.append(parse_ident(token))
 
-    return idx, [DbTableName(table) for table in tables]
+    return idx, [DbTableMeta(table) for table in tables]
 
 
 class SqlMeta:
-    def __init__(self, in_tables: List[DbTableName], out_tables: List[DbTableName]):
+    def __init__(self, in_tables: List[DbTableMeta], out_tables: List[DbTableMeta]):
         self.in_tables = in_tables
         self.out_tables = out_tables
 
     def __repr__(self):
         return f"SqlMeta({self.in_tables!r},{self.out_tables!r})"
 
-    def add_in_tables(self, in_tables: List[DbTableName]):
+    def add_in_tables(self, in_tables: List[DbTableMeta]):
         for in_table in in_tables:
             self.in_tables.append(in_table)
 
-    def add_out_tables(self, out_tables: List[DbTableName]):
+    def add_out_tables(self, out_tables: List[DbTableMeta]):
         for out_table in out_tables:
             self.out_tables.append(out_table)
 
@@ -116,29 +186,6 @@ class SqlParser:
         self.intables = set()
         self.outtables = set()
 
-    @classmethod
-    def parse(cls, sql: str, default_schema: Optional[str] = None) -> SqlMeta:
-        if sql is None:
-            raise ValueError("A sql statement must be provided.")
-
-        # Tokenize the SQL statement
-        sql_statements = sqlparse.parse(sql)
-
-        sql_parser = cls(default_schema)
-        sql_meta = SqlMeta([], [])
-
-        for sql_statement in sql_statements:
-            tokens = TokenList(sql_statement.tokens)
-            log.debug(f"Successfully tokenized sql statement: {tokens}")
-
-            result = sql_parser.recurse(tokens)
-
-            # Add the in / out tables (if any) to the sql meta
-            sql_meta.add_in_tables(result.in_tables)
-            sql_meta.add_out_tables(result.out_tables)
-
-        return sql_meta
-
     def recurse(self, tokens: TokenList) -> SqlMeta:
         in_tables, out_tables = set(), set()
         idx, token = tokens.token_next_by(t=T.Keyword)
@@ -191,3 +238,30 @@ class SqlParser:
             # Parse CTE using recursion.
             return cte_name.value, self.recurse(TokenList(parens.tokens)).in_tables
         raise RuntimeError(f"Parens {parens} are not Parenthesis at index {gidx}")
+
+
+def parse(
+    sql: str,
+    dialect: Optional[str] = None,
+    default_schema: Optional[str] = None
+) -> SqlMeta:
+    if sql is None:
+        raise ValueError("A sql statement must be provided.")
+
+    # Tokenize the SQL statement
+    sql_statements = sqlparse.parse(sql)
+
+    sql_parser = SqlParser(default_schema)
+    sql_meta = SqlMeta([], [])
+
+    for sql_statement in sql_statements:
+        tokens = TokenList(sql_statement.tokens)
+        log.debug(f"Successfully tokenized sql statement: {tokens}")
+
+        result = sql_parser.recurse(tokens)
+
+        # Add the in / out tables (if any) to the sql meta
+        sql_meta.add_in_tables(result.in_tables)
+        sql_meta.add_out_tables(result.out_tables)
+
+    return sql_meta
