@@ -63,6 +63,7 @@ def match(expected, result) -> bool:
                 return False
     elif isinstance(expected, list):
         if len(expected) != len(result):
+            log.error(f"Length does not match: expected {len(expected)} result: {result}")
             return False
 
         # Try to resolve case where we have wrongly sorted lists by looking at name attr
@@ -71,18 +72,27 @@ def match(expected, result) -> bool:
             if 'name' in x:
                 matched = False
                 for y in result:
-                    if 'name' in y and x['name'] == y['name']:
-                        if not match(x, y):
-                            return False
-                        matched = True
-                        break
+                    if 'name' in y:
+                        expected_name = env.from_string(x['name']).render()
+                        result_name = env.from_string(y['name']).render()
+                        if expected_name == result_name:
+                            if not match(x, y):
+                                log.error(f"List not matched {x} where {y}")
+                                return False
+                    matched = True
+                    break
                 if not matched:
+                    log.error(
+                        f"List not matched - no same stuff for {x} "
+                        f"in expected: {expected} result {result}"
+                    )
                     return False
             else:
                 if not match(x, result[i]):
+                    log.error(f"List not matched expected: {x} result: {result[i]}")
                     return False
     elif isinstance(expected, str):
-        if expected.lstrip().startswith('{{'):
+        if '{{' in expected:
             # Evaluate jinja: in some cases, we want to check only if key exists, or if
             # value has the right type
             rendered = env.from_string(expected).render(result=result)
@@ -91,7 +101,9 @@ def match(expected, result) -> bool:
             log.error(f"Rendered value {rendered} does not equal 'true' or {result}")
             return False
         elif expected != result:
+            log.error(f"Expected value {expected} does not equal result {result}")
             return False
     elif expected != result:
+        log.error(f"Object of type {type(expected)}: {expected} does not match {result}")
         return False
     return True
